add_paper: Add a new paper

View source: R/init_project.R

add_paperR Documentation

Add a new paper

Description

Set up directory structure for a new paper and adds a papaja template to an existing project repository.

Usage

add_paper(x = ".", shorttitle)

Arguments

x

Character. Path to project repository.

shorttitle

Character. Short title of the paper used as directory name.


crsh/template documentation built on Dec. 5, 2023, 6:31 p.m.