| add_paper | R Documentation |
Set up directory structure for a new paper and adds a papaja template to an existing project repository.
add_paper(x = ".", shorttitle)
x |
Character. Path to project repository. |
shorttitle |
Character. Short title of the paper used as directory name. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.